@@ -7,289 +7,300 @@
 # nocov
 
 bayesian_make <- function(modes = c("classification", "regression")) {
-  parsnip::set_new_model("bayesian")
+  model <- "bayesian"
+  engine <- "brms"
+
+  fitfunc <- c(pkg = "bayesian", fun = "bayesian_fit")
+  predfunc <- c(pkg = "bayesian", fun = "bayesian_predict")
+
+  dependpkgs <- unique(c("brms", fitfunc["pkg"], predfunc["pkg"]))
+  dependpkgs <- dependpkgs[!is.na(dependpkgs)]
+
+  parsnip::set_new_model(model)
 
   for (mode in modes) {
-    parsnip::set_model_mode("bayesian", mode)
+    parsnip::set_model_mode(model = model, mode = mode)
 
     # -------------------------------------------------------------------------
 
-    parsnip::set_model_engine("bayesian", mode, "brms")
+    parsnip::set_model_engine(model = model, mode = mode, eng = engine)
 
-    parsnip::set_dependency("bayesian", "brms", "brms")
-    parsnip::set_dependency("bayesian", "brms", "bayesian")
+    # -------------------------------------------------------------------------
+
+    for (pkg in dependpkgs) {
+      parsnip::set_dependency(model = model, eng = engine, pkg = pkg)
+    }
+
+    # -------------------------------------------------------------------------
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
-      parsnip = "mode",
-      original = "mode",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
-      has_submodel = FALSE
-    )
-
-    parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "formula.override",
       original = "formula.override",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "family",
       original = "family",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "prior",
       original = "prior",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "sample_prior",
       original = "sample_prior",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "knots",
       original = "knots",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "stanvars",
       original = "stanvars",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "fit",
       original = "fit",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "inits",
       original = "inits",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "chains",
       original = "chains",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "iter",
       original = "iter",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "warmup",
       original = "warmup",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "thin",
       original = "thin",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "cores",
       original = "cores",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "threads",
       original = "threads",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "algorithm",
       original = "algorithm",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "backend",
       original = "backend",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "stan_args",
       original = "stan_args",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "control",
       original = "control",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "save_pars",
       original = "save_pars",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "save_model",
       original = "save_model",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "file",
       original = "file",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "file_refit",
       original = "file_refit",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "normalize",
       original = "normalize",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "future",
       original = "future",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "seed",
       original = "seed",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
     parsnip::set_model_arg(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       parsnip = "silent",
       original = "silent",
-      func = c(pkg = "bayesian", fun = "bayesian_fit"),
+      func = fitfunc,
       has_submodel = FALSE
     )
 
+    # -------------------------------------------------------------------------
+
     parsnip::set_fit(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       mode = mode,
       value = list(
         interface = "formula",
         protect = c("formula", "data"),
-        func = c(pkg = "bayesian", fun = "bayesian_fit"),
+        func = fitfunc,
         defaults = list()
       )
     )
 
+    # -------------------------------------------------------------------------
+
     parsnip::set_encoding(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       mode = mode,
       options = list(
-        predictor_indicators = "traditional",
-        compute_intercept = TRUE,
-        remove_intercept = TRUE,
+        predictor_indicators = "none",
+        compute_intercept = FALSE,
+        remove_intercept = FALSE,
         allow_sparse_x = FALSE
       )
     )
 
+    # -------------------------------------------------------------------------
+
     if (mode == "classification") {
       parsnip::set_pred(
-        model = "bayesian",
-        eng = "brms",
+        model = model,
+        eng = engine,
         mode = mode,
         type = "class",
         value = list(
@@ -311,7 +322,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
             }
             unname(results)
           },
-          func = c(pkg = "bayesian", fun = "bayesian_predict"),
+          func = predfunc,
           args = list(
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
@@ -321,8 +332,8 @@ bayesian_make <- function(modes = c("classification", "regression")) {
       )
 
       parsnip::set_pred(
-        model = "bayesian",
-        eng = "brms",
+        model = model,
+        eng = engine,
         mode = mode,
         type = "prob",
         value = list(
@@ -344,7 +355,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
             }
             results
           },
-          func = c(pkg = "bayesian", fun = "bayesian_predict"),
+          func = predfunc,
           args = list(
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
@@ -354,8 +365,8 @@ bayesian_make <- function(modes = c("classification", "regression")) {
       )
     } else {
       parsnip::set_pred(
-        model = "bayesian",
-        eng = "brms",
+        model = model,
+        eng = engine,
         mode = mode,
         type = "numeric",
         value = list(
@@ -363,7 +374,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           post = function(results, object) {
             tibble::tibble(.pred = results[, 1])
           },
-          func = c(pkg = "bayesian", fun = "bayesian_predict"),
+          func = predfunc,
           args = list(
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
@@ -374,8 +385,8 @@ bayesian_make <- function(modes = c("classification", "regression")) {
     }
 
     parsnip::set_pred(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       mode = mode,
       type = "conf_int",
       value = list(
@@ -420,7 +431,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           }
           res
         },
-        func = c(pkg = "bayesian", fun = "bayesian_predict"),
+        func = predfunc,
         args = list(
           object = rlang::expr(object$fit),
           newdata = rlang::expr(new_data),
@@ -430,8 +441,8 @@ bayesian_make <- function(modes = c("classification", "regression")) {
     )
 
     parsnip::set_pred(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       mode = mode,
       type = "pred_int",
       value = list(
@@ -476,7 +487,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
           }
           res
         },
-        func = c(pkg = "bayesian", fun = "bayesian_predict"),
+        func = predfunc,
         args = list(
           object = rlang::expr(object$fit),
           newdata = rlang::expr(new_data),
@@ -486,14 +497,14 @@ bayesian_make <- function(modes = c("classification", "regression")) {
     )
 
     parsnip::set_pred(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       mode = mode,
       type = "raw",
       value = list(
         pre = NULL,
         post = NULL,
-        func = c(pkg = "bayesian", fun = "bayesian_predict"),
+        func = predfunc,
         args = list(
           object = rlang::expr(object$fit),
           newdata = rlang::expr(new_data),
@@ -503,8 +514,8 @@ bayesian_make <- function(modes = c("classification", "regression")) {
     )
 
     parsnip::set_pred(
-      model = "bayesian",
-      eng = "brms",
+      model = model,
+      eng = engine,
       mode = mode,
       type = "quantile",
       value = list(
@@ -512,7 +523,7 @@ bayesian_make <- function(modes = c("classification", "regression")) {
         post = function(results, object) {
           tibble::as_tibble(results)
         },
-        func = c(pkg = "bayesian", fun = "bayesian_predict"),
+        func = predfunc,
         args = list(
           object = rlang::expr(object$fit),
           newdata = rlang::expr(new_data),
